import React, { ChangeEvent, Component, MouseEvent } from 'react';

type GetNameProps = {
  updateName: (name: string) => void
};
type GetNameState = {
  name: string
};

// In this version of this app, GetName manages some state - in particular,
// any intermediate steps for the user's input. Once it's done, it updates
// the name of the parent component via updateName.
//
// Note how this component handles the edge cases for the input, not the parent
export class GetName extends Component<GetNameProps, GetNameState> {

  constructor(props: GetNameProps) {
    super(props);

    this.state = { name: "" };
  }

  render = (): JSX.Element => {
    return <p>What is your name?{" "}
        <input type="text" value={this.state.name} onChange={this.doNameChange} />
        <button onClick={this.doDoneClick}>Done</button>
      </p>
  };

  doNameChange = (evt: ChangeEvent<HTMLInputElement>): void => {
    this.setState({ name: evt.target.value });
  };

  doDoneClick = (_evt: MouseEvent<HTMLButtonElement>): void => {
    // in an ideal case, we should disable the "done" button instead,
    // which can be done with disabled={this.state.trim() === ""}
    // but this version is simpler!
    if (this.state.name.trim() === "") {
      return;
    }

    this.props.updateName(this.state.name);
  };
}
