import React, { Component } from 'react';
import { Greeting } from './Greeting';
import { Language } from './language';
import { LanguageSelect } from './LanguageSelect';
import { GetName } from './GetName';

type HelloAppProps = {};
type HelloAppState = {
  showGreeting: boolean,
  name: string,
  language: Language,
};

// In this version of the app, HelloApp is much simpler: it manages
// the overall "view" the user sees (whether they're in the "GetName")
// or "Greeting" phase of the app. It delegates individual error handling,
// etc. to the individual components. Note how the update* methods are
// *not* event handlers - this logic is handled by the individual components.
//
// Note that this is further than what we covered in lecture.
export class HelloApp extends Component<HelloAppProps, HelloAppState> {

  constructor(props: HelloAppProps) {
    super(props);

    this.state = { showGreeting: false, name: "", language: "en" };
  }

  render = (): JSX.Element => {
    // This ternary makes the code terser, but it's the same as an if statement.
    return <>
      {this.state.showGreeting
        ? <Greeting name={this.state.name} language={this.state.language} />
        : <GetName updateName={this.updateName} />}
      <LanguageSelect language={this.state.language} updateLanguage={this.updateLanguage} />
    </>;
  };

  updateLanguage = (newLanguage: Language): void => {
    this.setState({ language: newLanguage });
  }

  updateName = (newName: string): void => {
    this.setState({ name: newName, showGreeting: true });
  }
}
