import React, { ChangeEvent, Component } from 'react';
import { Language } from './language';

type LanguageSelectProps = {
  language: Language,
  updateLanguage: (language: Language) => void
};
type LanguageSelectState = {};

// In this version of this app, the LanguageSelect component is stateless
// and handles the "implementation" of the <select> option. However, note
// that the updateLanguage prop does *not* take in a ChangeEvent, but rather
// just a language. This means that, down the line, we could change
// the implementation of this select to be something else (e.g. an <input>)
// without affecting clients of our component.
// (this is a slight adjustment from what we showed in lecture)
export class LanguageSelect extends Component<LanguageSelectProps, LanguageSelectState> {

  constructor(props: LanguageSelectProps) {
    super(props);
  }

  render = (): JSX.Element => {
    return <select onChange={this.doLanguageChange} value={this.props.language}>
      <option value="en">English</option>
      <option value="es">Spanish</option>
      <option value="jp">Japanese</option>
    </select>
  }

  doLanguageChange = (evt: ChangeEvent<HTMLSelectElement>): void => {
    const newLanguage = evt.target.value;

    // Among other things, this if statement helps us better use TypeScript's
    // type narrowing feature -- observe how the type hint for newLanguage
    // *changes* after this if statement.
    if (!(newLanguage === "en" || newLanguage === "es" || newLanguage === "jp")) {
      throw new Error(`Invalid language: ${newLanguage}`);
    }

    this.props.updateLanguage(newLanguage)
  }
}
